"""
Wrapper for aioboto3 MigrationHub service.

[Documentation](https://youtype.github.io/types_aioboto3_docs/types_aiobotocore_mgh/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto34.aioboto3 import Session

    # Wrapper for aioboto3.Session constructor
    # Returns boto34.Session inherited from aioboto3.Session
    session = Session()
    session: boto34.aioboto3.session.Session

    # Type annotated aioboto3.Client
    # Uses the same arguments as aioboto3.client method
    # Returns type annotated aioboto3 MigrationHub client
    mgh_client = session.mgh.client()
    mgh_client: types_aiobotocore_mgh.client.MigrationHubClient
    ```
"""

from __future__ import annotations

from boto34.aioboto3.service_factory import ServiceFactory

try:
    from types_aiobotocore_mgh.client import MigrationHubClient
except ImportError:
    MigrationHubClient = object  # type: ignore[misc,assignment]


class MigrationHubService(
    ServiceFactory[MigrationHubClient]  # type: ignore[misc,assignment]
):
    SERVICE_NAME = "mgh"
    _SERVICE_PROP = "mgh"
