"""
Wrapper for aioboto3 CloudWatchObservabilityAccessManager service.

[Documentation](https://youtype.github.io/types_aioboto3_docs/types_aiobotocore_oam/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto34.aioboto3 import Session

    # Wrapper for aioboto3.Session constructor
    # Returns boto34.Session inherited from aioboto3.Session
    session = Session()
    session: boto34.aioboto3.session.Session

    # Type annotated aioboto3.Client
    # Uses the same arguments as aioboto3.client method
    # Returns type annotated aioboto3 CloudWatchObservabilityAccessManager client
    oam_client = session.oam.client()
    oam_client: types_aiobotocore_oam.client.CloudWatchObservabilityAccessManagerClient
    ```
"""

from __future__ import annotations

from boto34.aioboto3.service_factory import ServiceFactory

try:
    from types_aiobotocore_oam.client import CloudWatchObservabilityAccessManagerClient
except ImportError:
    CloudWatchObservabilityAccessManagerClient = object  # type: ignore[misc,assignment]


class CloudWatchObservabilityAccessManagerService(
    ServiceFactory[CloudWatchObservabilityAccessManagerClient]  # type: ignore[misc,assignment]
):
    SERVICE_NAME = "oam"
    _SERVICE_PROP = "oam"
